import React, { Fragment } from 'react';
import { Drawer, Button, Spin, Descriptions, Badge, Card } from 'antd';
import { getAnchorDetail } from '@/services/manage';
import { PageHeaderWrapper } from '@ant-design/pro-layout';
import Url from '@/utils/Url';
import * as Format from '@/utils/Format';
import Zmage from 'react-zmage';
import Ellipsis from '../Ellipsis';
import router from 'umi/router';
import styles from './DemoDetail';

class DemoDetail extends React.Component {
  constructor(props) {
    super(props);
    this.state = {
      loading: false,
      userId: Url.getQueryString('userId'),
      info: { userProfile: {} },
    };
  }

  componentDidMount() {
    this.getAnchorDetail(); //获取主播详情
  }

  //获取主播详情
  getAnchorDetail() {
    const { loading, userId } = this.state;
    this.setState({ loading: true }, async () => {
      const res = await getAnchorDetail({ userId });
      if (res.success) {
        const info = res.data || {};
        info.userProfile = info.userProfile || {};
        this.setState({ loading: false, info });
      } else {
        this.setState({ loading: false });
      }
    });
  }

  testLog() {
    console.log(this.state);
  }

  render() {
    const { loading, info } = this.state;
    return (
      <PageHeaderWrapper
        title={<span onClick={this.testLog.bind(this)}>主播详情</span>}
        onBack={() => router.goBack()}
      >
        <Card loading={loading}>
          <Descriptions title="基础信息">
            <Descriptions.Item label="头像">
              <Zmage
                style={{ width: 50, height: 50, borderRadius: '50%' }}
                src={info.userProfile.userAvatar}
              ></Zmage>
            </Descriptions.Item>
            <Descriptions.Item label="名称">{info.userName}</Descriptions.Item>
            <Descriptions.Item label="创建时间">
              {Format.date(info.userCreateTime, 'yyyy-MM-dd HH:mm')}
            </Descriptions.Item>
            <Descriptions.Item label="审核时间">
              {Format.date(info.anchorAuthTime, 'yyyy-MM-dd HH:mm')}
            </Descriptions.Item>
            <Descriptions.Item label="直播状态">
              {info.liveStatus === 101 && <Badge status="processing" text="直播中" />}
              {info.liveStatus === 201 && <Badge status="default" text="未开播" />}
            </Descriptions.Item>
            <Descriptions.Item label="推流状态">
              {info.streamStatus === 101 && <Badge status="processing" text="推流中" />}
              {info.streamStatus === 201 && <Badge status="default" text="已关闭" />}
            </Descriptions.Item>
            <Descriptions.Item label="个性签名">
              <Ellipsis tooltip length={20} style={{ display: 'contents' }}>
                {info.userProfile.userSign}
              </Ellipsis>
            </Descriptions.Item>
          </Descriptions>
        </Card>
      </PageHeaderWrapper>
    );
  }
}

export default DemoDetail;
