import React from 'react'
import { DatePicker } from 'antd'
import moment from 'moment'
import styles from './TimeRange.less'
import 'moment/locale/zh-cn'
moment.locale('zh-cn')
import { MyDate } from '@/utils/base'

const { RangePicker } = DatePicker
const dateFormat = 'YYYY-MM-DD'
const timeQuickList = [
  { key: 1, title: '今日', type: 'today' },
  { key: 2, title: '昨日', type: 'yesterday' },
  { key: 3, title: '本周', type: 'week' },
  { key: 4, title: '上周', type: 'lastWeek' },
  { key: 5, title: '本月', type: 'month' },
  { key: 6, title: '上月', type: 'lastMonth' },
  { key: 7, title: '前7天', type: 7 },
  { key: 8, title: '前15天', type: 15 },
  { key: 9, title: '前30天', type: 30 },
]
const Footer = ({ onClick, active }) => (
  <div className={styles['time-range-footer-wrap']}>
    {
      timeQuickList .map((item) => (
        <div key={item.key}>
          <a
            href='#'
            onClick={e => {
              e.preventDefault()
              onClick && onClick(item)
            }}
            className={ active === item.key ? styles['active'] : '' }
          >
            {item.title}
          </a>
        </div>
      ))
    }
  </div>
)
class TimeRange extends React.Component {
  state = {
    active: 0,
    open: false
  }
  setFooter = () => {
    const { active } = this.state
    return (
      <Footer
        active={active}
        onClick={this.footerClick}
      />
    )
  }
  footerClick = item => {
    const { type } = item
    const { onChange } = this.props
    onChange && onChange(MyDate.getTimeDistance(type))
    this.setState({ open: false, active: item.key })
  }
  handleTime = (moments) => {
    const { onChange } = this.props
    onChange && onChange(moments)
    this.setState({ open: false, active: 0 })
  }

  onOpenChange = (stats) => {
    this.setState({ open: stats })
  }

  render () {
    const { showFooter } = this.props
    const { open } = this.state
    return (
      <RangePicker
        ref={instance => this.pickerInstance = instance}
        dropdownClassName={
          showFooter
          ? styles['time-range']
          : `${styles['time-range']} ${styles['hide-footer']}`
        }
        renderExtraFooter={showFooter && this.setFooter}
        {...this.props}
        onChange={this.handleTime}
        open={open}
        onOpenChange={this.onOpenChange}
      />
    )
  }
}
export default TimeRange
