import { Avatar, Icon, Menu, Spin } from 'antd';
import React from 'react';
import { connect } from 'dva';
import router from 'umi/router';
import HeaderDropdown from '../HeaderDropdown';
import styles from './index.less';
import { ResetPassword } from '@/components/Modals'

class AvatarDropdown extends React.Component {
  onMenuClick = event => {
    const { key } = event;
    const { currentUser } = this.props
    if (key === 'logout') {
      const { dispatch } = this.props;

      if (dispatch) {
        dispatch({
          type: 'login/logout',
        });
      }

      return;
    } else if (key === 'resetPassword') {
      if (!currentUser || !currentUser.adminId) return
      ResetPassword({
        currentUser,
        onOk: () => {}
      })
      return
    }

    router.push(`/account/${key}`);
  };

  render() {
    const {
      currentUser = {
        adminAvatar: '',
        adminName: '',
      },
      menu,
    } = this.props;
    const menuHeaderDropdown = (
      <Menu className={styles.menu} selectedKeys={[]} onClick={this.onMenuClick}>
        {menu && (
          <Menu.Item key="center">
            <Icon type="user" />
            个人中心
          </Menu.Item>
        )}
        {menu && (
          <Menu.Item key="settings">
            <Icon type="setting" />
            个人设置
          </Menu.Item>
        )}
        {menu && <Menu.Divider />}
        <Menu.Item key="resetPassword">
          <Icon type="edit" />
          修改密码
        </Menu.Item>
        <Menu.Item key="logout">
          <Icon type="logout" />
          退出登录
        </Menu.Item>
      </Menu>
    );
    return (
      <HeaderDropdown overlay={menuHeaderDropdown}>
        <span className={`${styles.action} ${styles.account}`}>
          <Avatar size="small" className={styles.avatar} src={currentUser.adminAvatar || require('@/assets/logo.png')} alt="avatar" />
          <span className={styles.name} style={{padding: currentUser.adminName ? 'unset' : '0 20px'}}>{currentUser.adminName}</span>
        </span>
      </HeaderDropdown>
    )
    // : (
    //   <Spin
    //     size="small"
    //     style={{
    //       marginLeft: 8,
    //       marginRight: 8,
    //     }}
    //   />
    // );
  }
}

export default connect(({ user }) => ({
  currentUser: user.currentUser,
}))(AvatarDropdown);
