import React, { Component } from 'react'
import { Modal, notification, Input } from 'antd'

const { TextArea } = Input

class ModalInput extends Component {
  constructor (props) {
    super(props)
    this.state = {
      loading: false,
      remark: ''
    }
  }
  componentDidMount () {
    const { exist } = this.props 
    if (exist) {
      this.setState({ remark: exist })
    }
  }
  showError = (description) => {
    notification.error({
      message: '提示',
      description
    })
  }

  onRemark = (e) => {
    const { value } = e.target
    this.setState({ remark: value })
  }

  onOk = () => {
    const { remark } = this.state
    const { 
      onOk, 
      required, 
      placeholder = '请输入理由',
      pattern,
      patterNotice
    } = this.props
    if (required && !remark) {
      this.showError(placeholder)
      return 
    }
    if (pattern && !pattern.test(remark)) {
      this.showError(patterNotice)
      return
    }
    let cb = onOk && onOk(remark)
    let cbType = Object.prototype.toString.call(cb)
    if (cbType.indexOf('Promise') !== -1) {
      // promise
      this.setState({ loading: true })
      return cb
      .then(() => {
        // 啥也不做
      })
    } 
  }
  render () {
    const { loading, remark } = this.state
    const { 
      width = 520, 
      title = '输入', 
      onCancel, 
      placeholder = '请输入理由'
     } = this.props
    let _okButtonProps = {
      loading
    }
    return (
      <Modal
        visible
        centered
        width={width}
        title={title}
        onOk={this.onOk}
        onCancel={onCancel}
        okButtonProps={_okButtonProps}
        okText='确定'
        cancelText='取消'
      >
        <div>
          <TextArea 
            value={remark}
            onChange={this.onRemark}
            placeholder={placeholder}
            style={{resize: 'none', height: 100}}
          />
        </div>
      </Modal>
    )
  }
}
export default ModalInput
