/**
 * 
 * 主播列表 筛选条件
 */
import React, { Component } from 'react'
import styles from './AuditFilters.less'
import { Select, Input, Button, DatePicker, InputNumber } from 'antd'
import moment from 'moment'
import { regIntNumber } from '@/utils/base'
import { applyTypes, auditStatus as auditStatusArray } from '../common'

const Option = Select.Option
const RangePicker = DatePicker.RangePicker
const _style = {
  width: '100%'
}
class Filters extends Component {
  onInput = (e) => {
    const { value } = e.target
    if (value && !regIntNumber.test(value)) {
      return
    }
    const { onChange } = this.props
    onChange && onChange('agentNo', value)
  }
  onUserName = (e) => {
    const { value } = e.target
    const { onChange } = this.props
    onChange && onChange('userName', value)
  }
  // 状态申请类型
  onApplyType = key => {
    const { onChange } = this.props
    onChange && onChange('applyType', key)
  }
  // 审核状态
  onAuditStatus = key => {
    const { onChange } = this.props
    onChange && onChange('auditStatus', key)
  }
  // 时间筛选
  onDateChange = (moments, strArray) => {
    let _startTime
    let _endTime
    if (strArray && strArray.length) {
      _startTime = new Date(strArray[0] + ' 00:00:00').getTime() // moments[0].valueOf()
      _endTime = new Date(strArray[1] + ' 23:59:59').getTime() // moments[1].valueOf()
    }
    const { onChange } = this.props
    onChange && onChange([{ name: 'startTime', value: _startTime }, { name: 'endTime', value: _endTime }])
  }
  render () {
    const { applyType, onSearch, auditStatus, userName, startTime, endTime } = this.props
    return (
      <div className={styles['wrap']}>
        <div className={styles['filter-item']}>
          <h4 className={styles['filter-label']}>主播昵称:</h4>
          <Input 
            placeholder='请输入主播昵称'
            style={_style}
            value={userName}
            onChange={this.onUserName}
            allowClear
          />
        </div>
        <div className={styles['filter-item']}>
          <h4 className={styles['filter-label']}>申请类型:</h4>
          <Select
            style={_style}
            placeholder='请选择申请类型'
            value={applyType}
            onChange={this.onApplyType}
            allowClear
          >
            <Option key='all'>全部</Option>
            {
              applyTypes && applyTypes.map((item) => (
                <Option key={item.key}>{item.value}</Option>
              ))
            }
          </Select>
        </div>
        <div className={styles['filter-item']}>
          <h4 className={styles['filter-label']}>审核状态:</h4>
          <Select
            style={_style}
            placeholder='请选择审核状态'
            value={auditStatus}
            onChange={this.onAuditStatus}
            allowClear
          >
            <Option key='all'>全部</Option>
            {
              auditStatusArray && auditStatusArray.map((item) => (
                <Option key={item.key}>{item.value}</Option>
              ))
            }
          </Select>
        </div>
        
        <div className={`${styles['filter-item']} ${styles['filter-item-time']}`} hidden>
          <h4 className={styles['filter-label']}>申请时间:</h4>
          <RangePicker 
            style={_style}
            onChange={this.onDateChange}
            value={startTime ? [moment(startTime), moment(endTime)] : undefined}
          />
        </div>
        <div className={styles['btn-wrap']}>
          <Button
            icon='search'
            onClick={onSearch}
            type='primary'
          >搜索</Button>
        </div>
      </div>
    )
  }
}
export default Filters
