/**
 * 
 * 统计图表
 */
import React, { Component } from 'react'
import { PageHeaderWrapper } from '@ant-design/pro-layout'
import { Card, Row, Col, Icon, Tooltip, Spin, Button } from 'antd' 
import styles from './CountCharts.less'
import numeral from 'numeral'
import router from 'umi/router'
import { getCurrentAndYesterdayStat } from './api'
import Decimal from 'decimal.js'
import { TimeRange } from '@/components/Filters'

// 小卡片样式
const _col = {
  md: { span: 6 },
  style: { padding: '0 5px', marginBottom: 10 }
}
class CountCharts extends Component {
  constructor (props) {
    super(props)
    this.state = {
      // 统计列表
      list: [],
      // 加载
      loading: false
    }
  }

  componentDidMount () {
    this.onInit()
  }
  // 获取初始值
  onInit = async () => {
    const _state = {
      loading: false
    }
    try {
      // 设置loading
      this.setState({
        loading: true
      })
      const { code, data } = await getCurrentAndYesterdayStat()
      if (code === 'OK' && data) {
        _state.list = data.list || []
      }
    } catch (e) {
      console.log(e)
    }
    this.setState(_state)
  }

  // 格式化数据，可能是数量不一定就是金额
  formateNumber = (num) => {
    if (!num) {
      return num
    }
    // 根据传入的数值，区分是否有.做不同的格式
    // 因为数量不能有小数
    if (num.indexOf('.') !== -1) {
      return numeral(num).format('0,0.00')
    }
    return numeral(num).format('0,0') 
  }

  // 跳转到下一级
  goDetails = ({ statType }) => e => {
    router.push({
      pathname: '/statistics/charts/details',
      query: {
        statType
      }
    })
  }
  // 格式化百分比 乘100 加 百分号%
  formatPercent = (num) => {
    return new Decimal(num).mul(new Decimal(100)).toNumber()
  }
  render () {
    const { list, loading } = this.state
    return (
      <PageHeaderWrapper
        title='统计图表'
        extra={
          <div>
            <Button 
              type='primary' 
              icon='sync' 
              onClick={loading ? null : this.onInit} 
              loading={loading}
            >更新数据</Button>
          </div>
        }
      >
        <Spin spinning={loading}>
          {/* <TimeRange 
            showFooter
          /> */}
          <Row>
            {
              list && list.map((item, i) => (
                <Col key={i} {..._col}>
                  <Card className={styles['card-content']} onClick={this.goDetails(item)}>
                    <div className={styles['card-header']}>
                      <span>{item.statName || '下载次数'}</span>
                      {/* <Tooltip title={item.title || 'jdskskekk'}>
                        <Icon type="question-circle" />
                      </Tooltip> */}
                    </div>
                    <div className={styles['card-body']}>
                      <h3 className={styles['h3']}>
                        {/* <span>¥</span> */}
                        <strong>{this.formateNumber(item.currentValue)}</strong>
                      </h3>
                    <div className={styles['data-wrap']}>
                      <span>日同比:</span> 
                      <strong>{this.formatPercent(item.growthPercent)}%</strong>
                      <Icon 
                        type={item.growthPercent >= 0 ? 'caret-up' : 'caret-down'} 
                        style={{
                          color: item.growthPercent >= 0 ? 'red': 'green',
                          fontSize: 10,
                          marginLeft: 6
                        }} 
                      />
                    </div>
                    </div>
                    <div className={styles['card-footer']}>
                      <span>昨日数据:</span> 
                      <strong>{this.formateNumber(item.yesterdayValue)}</strong>
                    </div>
                  </Card>
                </Col>
              ))
            }
          </Row>
        </Spin>
      </PageHeaderWrapper>
    )
  }
}
export default CountCharts
