/**
 * 
 * 统计图表
 * 单个统计类型下 
 * 各个渠道的总和以及每个渠道的单独统计
 */
import React, { Component } from 'react'
import { PageHeaderWrapper } from '@ant-design/pro-layout'
import { Card, DatePicker, Button, Spin } from 'antd' 
import styles from './CountDetails.less'
import router from 'umi/router'
// 引入折线图表绘制函数
import { lineInit, totalLine } from './lineCharts'
// 引入柱状图绘制函数
import { barInit } from './barCharts'
// 引入接口获取数据函数
import { getAllChannel, getStatDetail } from './api'
// 获取时间 本日、本周、本月、本年等
import { MyDate, getStatPlatformType } from '@/utils/base'
// 图表绘制公共函数等
import { getXAxisArray } from './common'

const { RangePicker } = DatePicker

const _cardStyle = {
  marginBottom: 10
}
class CountDetails extends Component {
  constructor (props) {
    super(props)
    const [ startTime, endTime ] = MyDate.getTimeDistance('today')
    const statType = +props.location.query.statType
    this.state = {
      // 各个渠道
      channels: [],
      // 生命周期中 是否绘制图表的状态
      drawCharts: false,
      // 时间类型 根据timeType不同 传递不同参数，绘制不同时间轴
      timeType: 'today',
      // 开始时间
      startTime,
      // 结束时间
      endTime,
      // 统计类型值
      statType,
      // 统计类型值 对应的名称
      statName: getStatPlatformType(statType)
    }
  }

  componentDidMount () {
    this.onInit()
  }
  // didUpdate的时候根据条件去绘制图表
  componentDidUpdate (preProps, preState) {
    const { drawCharts } = this.state
    if (drawCharts && drawCharts !== preState.drawCharts) {
      console.log('-------- drawer --------')
      this.drawCharts()
    }
  }
  // 获取数据
  onInit = async () => {
    try {
      const { data, code } = await getAllChannel()
      if (code === 'OK' && data) {
        const channels = data || []
        this.setState({ channels }, this.getChannelData)
      }
    } catch (e) {
      console.log(e)
    }
  }

  // 循环获取各个渠道的数据
  getChannelData = async () => {
    const { channels } = this.state
    try {
      this.setState({ loading: true })
      const { statType, timeType, startTime, endTime } = this.state
      let statTimeType
      let _startTime
      let _endTime
      if (timeType === 'today') {
        statTimeType = 3
        _startTime = startTime.format('YYYYMMDD')
        _endTime = startTime.format('YYYYMMDD')
      } else if (timeType === 'week') {
        statTimeType = 4
        _startTime = startTime.format('YYYYMMDD')
        _endTime = endTime.format('YYYYMMDD')
      } else if (timeType === 'month') {
        statTimeType = 4
        _startTime = startTime.format('YYYYMMDD')
        _endTime = endTime.format('YYYYMMDD')
      } else {
        statTimeType = 1
        _startTime = startTime.format('YYYY')
        _endTime = startTime.format('YYYY')
      }
      // console.log(getXAxisArray({ timeType, startTime, endTime }))
      const { code, data } = await getStatDetail({ 
        statType, timeType: statTimeType, startTime: _startTime, endTime: _endTime
      })
      if (code === 'OK') {
        const { totalStat, channelStat } = data
        
        const _channels = []
        // 分出各个渠道的数据
        channels && channels.forEach((item) => {
          const _datas = this.getDataByChannnelId(item.channelId, channelStat, item)
          if (_datas === false) {
            // 不要
          } else {
            item.datas = _datas
            _channels.push(item)
          }
        })
        this.setState({ totalStat, channelStat, channels: _channels }, this.drawCharts)
      } 
    } catch (e) {
      console.log(e)
    }
    this.setState({ loading: false })
  }
  getDataByChannnelId = (channelId, channelStat, item) => {
    // status 1 启用 -1 删除 0 停用
    const { status } = item
    const { timeType, startTime, endTime } = this.state
    const fillArray = getXAxisArray({ timeType, startTime, endTime, isDataIndex: true })
    const fillArrayLen = fillArray.length
    let hasValue = false
    channelStat && channelStat.forEach((item) => {
      if (item.channelId === channelId) {
        hasValue = true
        for (let i = 0; i < fillArrayLen; i++) {
          if (fillArray[i].key === item.statTime) {
            fillArray[i].statValue = +item.statValue
            break
          }
        }
      }
    })
    // 已删除 无值的渠道不展示
    if (!hasValue && status !== 1) {
      return false
    }
    return fillArray
  }
  
  // 画图表
  drawCharts = () => {
    const { 
      channels, timeType, startTime, endTime,
      totalStat 
    } = this.state

    if (this.totalChat) {
      totalLine(this.totalChat, {
        timeType,
        startTime, 
        endTime,
        totalStat
      })
    }
    if (this.chartDetailsLine) {
      lineInit(this.chartDetailsLine, {
        timeType,
        channels,
        startTime, 
        endTime,
      })
    }
    channels && channels.forEach((item) => {
      barInit(this[`channel${item.channelId}`], {
        title: item.channelName,
        timeType,
        startTime, 
        endTime,
        channelInfo: item,
      })
    })

    this.setState({ drawCharts: false })
  }

  // 本日 、 本周 、 本月 、 本年
  getTimeType = (timeType) => {
    const [startTime, endTime] = MyDate.getTimeDistance(timeType)
    this.setState({ timeType, startTime, endTime }, () => {
      // 获取数据
      this.getChannelData()
    })
  }

  // 单天时间选择
  onDayChange = (date) => {
    this.setState({ startTime: date }, () => {
      // 获取数据
      this.getChannelData()
    })
  }

  // 时间范围的选择
  onRangeChange = ([startTime, endTime]) => {
    const oneDay = 1000 * 60 * 60 * 24;
    const _state = {}
    if ((endTime.valueOf() - startTime.valueOf()) <= oneDay) {
      _state.timeType = 'today'
    }
    _state.startTime = startTime
    _state.endTime = endTime
    this.setState(_state, () => {
      // 获取数据
      this.getChannelData()
    })
  }
  // 选择年
  onYearChange = (year, yearStr) => {
    this.setState({ startTime: year, yearPickerVisible: false }, () => {
      this.getChannelData()
    })
  }
  onOpenChange = (yearPickerVisible) => {
    this.setState({ yearPickerVisible })
  }

  // 根据条件设置 高亮
  getClassName = (name) => {
    const { startTime, endTime, timeType } = this.state 
    if (name !== timeType) {
      return ''
    }
    const [ _startTime, _endTime ] = MyDate.getTimeDistance(name)
    if (name === 'today') {
      // 不是同一天
      if (startTime.format('YYYYMMDD') !== _startTime.format('YYYYMMDD')) {
        return ''
      }
    }
    if (name === 'week' || name === 'month') {
      // 不是同一周或不是同一月
      if (
        startTime.format('YYYYMMDD') !== _startTime.format('YYYYMMDD') ||
        endTime.format('YYYYMMDD') !== _endTime.format('YYYYMMDD')
      ) {
        return ''
      }
    }
    if (name === 'year') {
      if (_startTime.format('YYYY') !== startTime.format('YYYY')) {
        return ''
      }
    }
    return styles['active'] 
  }
  
  render () {
    const { 
      channels, timeType, startTime, endTime, statName, yearPickerVisible,
      loading
    } = this.state
    return (
      <PageHeaderWrapper
        title={`${statName}统计图表`}
        extra={
          <div>
            <Button
              icon='left'
              onClick={router.goBack}
            >返回</Button>
          </div>
        }
      >
        <Spin spinning={loading}>
          <Card 
            title={`汇总图(${statName})`} 
            style={_cardStyle}
            extra={
              <div className={styles['time-filters']}>
                <div className={styles['time-btn-wrap']}>
                  <a 
                    href="#"
                    onClick={e => {
                      e.preventDefault()
                      this.getTimeType('today')
                    }}
                    className={this.getClassName('today')}
                  >本日</a>
                  <a 
                    href="#"
                    onClick={e => {
                      e.preventDefault()
                      this.getTimeType('week')
                    }}
                    className={this.getClassName('week')}
                  >本周</a>
                  <a 
                    href="#"
                    onClick={e => {
                      e.preventDefault()
                      this.getTimeType('month')
                    }}
                    className={this.getClassName('month')}
                  >本月</a>
                  <a 
                    href="#"
                    onClick={e => {
                      e.preventDefault()
                      this.getTimeType('year')
                    }}
                    className={this.getClassName('year')}
                  >本年</a>
                </div>
                {
                  timeType === 'today'
                  ? <DatePicker 
                    onChange={this.onDayChange}
                    value={startTime}
                    allowClear={false}
                  />
                  : timeType === 'week' || timeType === 'month'
                  ? <RangePicker 
                    onChange={this.onRangeChange}
                    value={[startTime, endTime]}
                    allowClear={false}
                  />
                  : <DatePicker 
                    mode='year'
                    format='YYYY'
                    onPanelChange={this.onYearChange}
                    value={startTime}
                    allowClear={false}
                    // ref={instance => this.yearPickerInstance = instance}
                    open={yearPickerVisible}
                    onOpenChange={this.onOpenChange}
                  />
                }
                
              </div>
            }
          >
            <div ref={node => this.totalChat = node} className={styles['line-charts']} />
          </Card>
          <Card style={_cardStyle} title={`渠道对比图(${statName})`}>
            <div ref={node => this.chartDetailsLine = node} className={styles['line-charts']} />
          </Card>
          {
            channels && channels.map((item) => (
              <Card 
                key={item.channelId} 
                title={`${item.channelName}(${statName})`} 
                style={_cardStyle}
              >
                <div 
                  className={styles['bar-charts']} 
                  ref={node => this[`channel${item.channelId}`] = node} 
                />
              </Card>
            ))
          }
        </Spin>
      </PageHeaderWrapper>
    )
  }
}
export default CountDetails
