/**
 * 
 * 时段统计
 */
import React, { Component } from 'react'
import { PageHeaderWrapper } from '@ant-design/pro-layout'
import router from 'umi/router'
import { Card, Menu, Spin } from 'antd'
import { FilterParts, DurationTableSimple, DurationTable, DurationCharts } from './components'
import { MyDate } from '@/utils/base'
import { getPeriodOverviewTop, getPeriodOverviewMiddle, getPeriodOverviewBottom } from './api'
import { TimeRange } from '@/components/Filters'
import styles from './DurationCount.less'
import moment from 'moment'
import { tabList } from './common'
import { durationMiddleLine } from './lineCharts'

const _cardStyle = {
  marginBottom: 10
}
const _cardBodyStyle = {
  padding: '10px 24px'
}
class DurationCount extends Component {
  constructor (props) {
    super(props)
    const [startTime, endTime] = MyDate.getTimeDistance('today')
    const [compareStartTime, compareEndTime] = MyDate.getTimeDistance('yesterday')
    this.state = {
      startTime, 
      endTime,
      compareStartTime,
      compareEndTime,
      topLoading: false,
      middleLoading: false,
      bottomLoading: false,
    }
  }
  componentDidMount () {
    this.getTop()
    this.getComparePart()
    this.getMiddle()
    this.getBottom()
  }

  // 格式化返回的今日昨日数据
  formatList = (data) => {
    const _data = {}
    const length = data.length

    data && data.forEach((item) => {
      _data[item.statType] = {
        value: item.statValue,
        title: item.statName
      }
    })
    return length ? [_data] : []
  }
  getTop = async () => {
    const _state = {
      topLoading: false
    }
    try {
      this.setState({ topLoading: true })
      const { startTime, endTime, channelId } = this.state
      const _params = {
        startDate: startTime.format('YYYYMMDD'),
        endDate: endTime.format('YYYYMMDD'),
      }
      const channelIds = channelId && channelId.filter(item => item !== 'all')
      if (channelIds && channelIds.length) {
        _params.channelIds = channelIds.toString()
      }
      const { code, data } = await getPeriodOverviewTop(_params)
      if (code === 'OK' && data) {
        _state.topList = this.formatList(data)
      }
    } catch (e) {
      console.log(e)
    } finally {
      this.setState(_state)
    }
  }

  // 中间固定部分
  getComparePart = async () => {
    const _state = {
      compareLoading: false
    }
    try {
      this.setState({ compareLoading: true })
      const { compareStartTime, compareEndTime, channelId } = this.state
      const _params = {
        startDate: compareStartTime.format('YYYYMMDD'),
        endDate: compareEndTime.format('YYYYMMDD'),
      }
      const channelIds = channelId && channelId.filter(item => item !== 'all')
      if (channelIds && channelIds.length) {
        _params.channelIds = channelIds.toString()
      }
      const { code, data } = await getPeriodOverviewTop(_params)
      if (code === 'OK' && data) {
        _state.compareParts = this.formatList(data)
      }
    } catch (e) {
      console.log(e)
    } finally {
      this.setState(_state)
    }
  }

  // 图表
  getMiddle = async (tagType = '101') => {
    const _state = {
      middleLoading: false
    }
    try {
      this.setState({ middleLoading: true })
      const { startTime, endTime, channelId } = this.state
      const _startTimeStr = startTime.format('YYYYMMDD')
      const _endTimeStr = endTime.format('YYYYMMDD')
      const _params = {
        startDate: _startTimeStr,
        endDate: _endTimeStr,
        tagType: tagType
      }
      const channelIds = channelId && channelId.filter(item => item !== 'all')
      if (channelIds && channelIds.length) {
        _params.channelIds = channelIds.toString()
      }
      const { code, data } = await getPeriodOverviewMiddle(_params) 
      if (code === 'OK' && data) {
        // durationMiddleLine
        const isToday = _startTimeStr === _endTimeStr && _startTimeStr === moment().format('YYYYMMDD')
        let _targetName = isToday ? '今日' : `${startTime.format('MM.DD')} ~ ${endTime.format('MM.DD')}`
        durationMiddleLine(this.middleChartRef, {
          middleData: data,
          targetDataName: _targetName,
          oneWeekAgoDataName: moment().subtract(7, 'days').format('MM.DD')
        })
        _state.tagType = tagType
      }
    } catch (e) {
      console.log(e)
    } finally {
      this.setState(_state)
    }
  }
  
  // 底部表格
  getBottom = async () => {
    const _state = {
      bottomLoading: false
    }
    try {
      this.setState({ bottomLoading: true })
      const { startTime, endTime, channelId } = this.state
      const _params = {
        startDate: startTime.format('YYYYMMDD'),
        endDate: endTime.format('YYYYMMDD'),
      }
      const channelIds = channelId && channelId.filter(item => item !== 'all')
      if (channelIds && channelIds.length) {
        _params.channelIds = channelIds.toString()
      }
      const { code, data } = await getPeriodOverviewBottom(_params)
      if (code === 'OK' && data) {
        const _result = []
        for (const attr in data) {
          const list = this.formatList(data[attr])
          const obj = list[0] || {}
          _result.push({
            key: attr,
            ...obj
          })
        }
        // 排序
        _result.sort((a, b) => { return (+a.key) - (+b.key) })
        _state.bottomTable = _result
      }
    } catch (e) {
      console.log(e)
    } finally {
      this.setState(_state)
    }
  }

  // 子组建内容变化
  onChange = (name, value) => {
    if (Array.isArray(name)) {
      let _state = {}
      name.map((item) => {
        _state[item.name] = item.value
      })
      this.setState(_state)
      return
    }
    this.setState({ [name]: value })
  }

  // 点击搜索
  onSearch = () => {
    this.getTop()
    const { tagType } = this.state
    this.getMiddle(tagType)
    this.getBottom()
    this.getComparePart()
  }

  // 比较列表点击时间筛选
  onConfirmChange = (moments) => {
    let _startTime
    let _endTime
    if (moments && moments.length) {
      _startTime = moments[0].startOf('date')
      _endTime = moments[1].endOf('date')
    }
    this.setState({
      compareStartTime: _startTime,
      compareEndTime: _endTime
    }, () => {
      this.getComparePart()
    })
  }

  // 中间切换
  onSelect = ({ key }) => {
    this.getMiddle(key)
    // this.setState({ current: key })
  }

  render () {
    const { 
      startTime, endTime, channelId, topList, compareParts, bottomTable,
      compareEndTime, compareStartTime,
      topLoading, middleLoading, compareLoading, bottomLoading
    } = this.state
    // console.log(startTime)
    return (
      <PageHeaderWrapper>
        <div className={styles['wrap']}>
          <FilterParts 
            startTime={startTime}
            endTime={endTime}
            channelId={channelId}
            onChange={this.onChange}
            onSearch={this.onSearch}
          />
          <Card style={_cardStyle} loading={topLoading}>
            <DurationTableSimple 
              dataSource={topList}
            />
          </Card>
          <Card 
            style={_cardStyle}
            title={<TimeRange 
              showFooter 
              onChange={this.onConfirmChange} 
              value={compareStartTime ? [moment(compareStartTime), moment(compareEndTime)] : undefined}
              allowClear={false}
            />}
            loading={compareLoading}
          >
            <DurationTableSimple 
              dataSource={compareParts}
            />
          </Card>
          <Card style={_cardStyle}>
            <div className={styles['menu-wrap']}>
              <Menu 
                mode="horizontal"
                onSelect={this.onSelect}
                selectedKeys={[this.state.tagType]}
              >
                {
                  tabList.map((item) => (
                    <Menu.Item tab={item.title} key={item.statType}>
                      {item.title}
                    </Menu.Item>
                  ))
                }
              </Menu>
              <Spin spinning={middleLoading}><div className={styles['chart-wrap']} ref={node => this.middleChartRef = node} /></Spin>
            </div> 
          </Card>
          <Card loading={bottomLoading}>
            <DurationTable 
              dataSource={bottomTable}
            />
          </Card>
        </div>
      </PageHeaderWrapper>
    )
  }
}
export default DurationCount
