/**
 * 
 * 用户访问趋势 统计
 */
import React, { Component } from 'react'
import { PageHeaderWrapper } from '@ant-design/pro-layout'
import router from 'umi/router'
import { Card, Menu, Table } from 'antd'
import { FilterParts, TotalTableSimple, TotalTable } from './components'
import { MyDate } from '@/utils/base'
import { getUserAccessTrend } from './api'
import styles from './TrendUserAccess.less'
import moment from 'moment'
import { tabList } from './common'
import { totalMiddleLine } from './lineCharts'

const _cardStyle = {
  marginBottom: 10
}
const _cardBodyStyle = {
  padding: '10px 24px'
}
const Column = Table.Column
class TrendUserAccess extends Component {
  constructor (props) {
    super(props)
    const [startTime, endTime] = MyDate.getTimeDistance(7)
    this.state = {
      startTime, 
      endTime
    }
  }
  componentDidMount () {
    this.getUserAccessTrend()
  }

  // 格式化返回的今日昨日数据
  formatList = (data) => {
    const _data = {}
    const length = data.length

    data && data.forEach((item) => {
      _data[item.statType] = {
        value: item.statValue,
        title: item.statName
      }
    })
    return length ? [_data] : []
  }
  
  getUserAccessTrend = async () => {
    const _state = {
      loading: false
    }
    try {
      this.setState({ loading: true })
      const { startTime, endTime, channelId } = this.state
      const _params = {
        startDate: startTime.format('YYYYMMDD'),
        endDate: endTime.format('YYYYMMDD'),
      }
      const channelIds = channelId && channelId.filter(item => item !== 'all')
      if (channelIds && channelIds.length) {
        _params.channelIds = channelIds.toString()
      }
      const { code, data } = await getUserAccessTrend(_params)
      if (code === 'OK' && data) {
        const _result = []
        for (const attr in data) {
          const list = this.formatList(data[attr])
          const obj = list[0] || {}
          _result.unshift({
            date: moment(attr).format('YYYY-MM-DD'),
            ...obj
          })
        }
        _state.bottomTable = _result
      }
    } catch (e) {
      console.log(e)
    } finally {
      this.setState(_state)
    }
  }

  // 子组建内容变化
  onChange = (name, value) => {
    if (Array.isArray(name)) {
      let _state = {}
      name.map((item) => {
        _state[item.name] = item.value
      })
      this.setState(_state)
      return
    }
    this.setState({ [name]: value })
  }

  // 点击搜索
  onSearch = () => {
    this.getUserAccessTrend()
  }

  render () {
    const { 
      startTime, endTime, channelId, topList, loading, bottomTable
    } = this.state
    // console.log(startTime)
    return (
      <PageHeaderWrapper>
        <div className={styles['wrap']}>
          <FilterParts 
            startTime={startTime}
            endTime={endTime}
            channelId={channelId}
            onChange={this.onChange}
            onSearch={this.onSearch}
          />
          <Card>
            <Table
              bordered
              rowKey={(record, i) => i}
              pagination={false}
              dataSource={bottomTable}
              loading={loading}
            >
              <Column 
                title='日期'
                key='date'
                dataIndex='date'
                render={(date, record) => (date)}
              />
              <Column 
                title='安装数'
                key='10200'
                dataIndex='10200'
                render={(obj, record) => (obj ? obj.value : '')}
              />
              <Column 
                title='注册用户数'
                key='10300'
                dataIndex='10300'
                render={(obj, record) => (obj ? obj.value : '')}
              />
              <Column 
                title='活跃用户数'
                key='10500'
                dataIndex='10500'
                render={(obj, record) => (obj ? obj.value : '')}
              />
              <Column 
                title='首充用户数'
                key='20300'
                dataIndex='20300'
                render={(obj, record) => (obj ? obj.value : '')}
              />
              <Column 
                title='未知(性别)'
                key='33100'
                dataIndex='33100'
                render={(obj, record) => (obj ? obj.value : '')}
              />
              <Column 
                title='男'
                key='33101'
                dataIndex='33101'
                render={(obj, record) => (obj ? obj.value : '')}
              />
              <Column 
                title='女'
                key='33102'
                dataIndex='33102'
                render={(obj, record) => (obj ? obj.value : '')}
              />
            </Table>
          </Card>
        </div>
      </PageHeaderWrapper>
    )
  }
}
export default TrendUserAccess
